.. _spkg_iniconfig:

iniconfig: Brain-dead simple config-ini parsing
=========================================================

Description
-----------

Brain-dead simple config-ini parsing

License
-------

Upstream Contact
----------------

https://pypi.org/project/iniconfig/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.0.0

version_requirements.txt::

    iniconfig


Equivalent System Packages
--------------------------

(none known)

